summaryrefslogtreecommitdiff
path: root/login
diff options
context:
space:
mode:
Diffstat (limited to 'login')
-rw-r--r--login/utmp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/login/utmp.c b/login/utmp.c
index e56f2c53..c7c1ac04 100644
--- a/login/utmp.c
+++ b/login/utmp.c
@@ -134,7 +134,7 @@ next_device(char *dev)
/* ---------------------------------------------------------------- */
/* Try and start the translator for CTL_PORT on NODE. If succesful, this
call will not return until the translator is stopped; otherwise it returns
an error code describing the reason why it couldn't start. */
static error_t
@@ -163,7 +163,7 @@ start_translator(file_t node, fsys_t ctl_port)
}
/* Find an unoccupied (one with no active translator) filename starting with
- NAME_PFX, and start the translator for CTL_PORT on it. If succesful, this
+ NAME_PFX, and start the translator for CTL_PORT on it. If successful, this
call will not return until the translator is stopped; otherwise it returns
an error code describing the reason why it couldn't start. When
successful, this function sets UTMP_NODE_NAME to the name of the file we
@@ -134,7 +134,7 @@ next_device(char *dev)
/* ---------------------------------------------------------------- */
-/* Try and start the translator for CTL_PORT on NODE. If succesful, this
+/* Try and start the translator for CTL_PORT on NODE. If successful, this
call will not return until the translator is stopped; otherwise it returns
an error code describing the reason why it couldn't start. */